#nvpl_rand-config.cmake
#
# Imported interface targets provided:
#  * nvpl::rand_static - static library target (if available)
#  * nvpl::rand_shared - shared library target
#  * nvpl::rand - alias to shared library target
#
#  * nvpl::rand_mt_static - static library target with multi-thread APIs (if available)
#  * nvpl::rand_mt_shared - shared library target with multi-thread APIs
#  * nvpl::rand_mt - alias to shared library target with multi-thread APIs
#
# Cache variables set:
#  * nvpl_rand_VERSION - Version of installed package
#  * nvpl_rand_INCLUDE_DIR - Location of nvpl_rand headers
#  * nvpl_rand_LIBRARY_DIR - Location of nvpl_rand libraries

set(nvpl_rand_VERSION "0.5.2")
# build: 31


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was nvpl_rand-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

## Find header and lib directories via known header and lib names
set(nvpl_rand_search_header_name nvpl_rand.h)
set(nvpl_rand_search_lib_name libnvpl_rand.so)
get_filename_component(nvpl_rand_search_prefix "${CMAKE_CURRENT_LIST_DIR}/../../" ABSOLUTE)

find_path(nvpl_rand_INCLUDE_DIR
          NAMES ${nvpl_rand_search_header_name}
          PATHS ${nvpl_rand_search_prefix}
          PATH_SUFFIXES
            ../include
            ../../include # Debian/Ubuntu aarch64
          NO_DEFAULT_PATH
          NO_CACHE) # Set cache variable after path normalization

find_path(nvpl_rand_LIBRARY_DIR
          NAMES ${nvpl_rand_search_lib_name}
          PATHS ${nvpl_rand_search_prefix}
          PATH_SUFFIXES lib lib64
          DOC "Location of nvpl_rand libraries"
          NO_DEFAULT_PATH)

# Check headers and library directories are found
if(NOT EXISTS "${nvpl_rand_INCLUDE_DIR}")
    message(FATAL_ERROR "Header directory containing file ${nvpl_rand_search_header_name} was not found relative to ${CMAKE_CURRENT_LIST_DIR}!")
endif()
if(NOT EXISTS "${nvpl_rand_LIBRARY_DIR}")
    message(FATAL_ERROR "Library directory containing file ${nvpl_rand_search_lib_name} was not found relative to ${CMAKE_CURRENT_LIST_DIR}!")
endif()

# Normalize nvpl_rand_INCLUDE_DIR and set cache variable
get_filename_component(nvpl_rand_INCLUDE_DIR "${nvpl_rand_INCLUDE_DIR}" ABSOLUTE)
set(nvpl_rand_INCLUDE_DIR ${nvpl_rand_INCLUDE_DIR} CACHE STRING "Location of nvpl_rand headers")

unset(nvpl_rand_search_header_name)
unset(nvpl_rand_search_lib_name)
unset(nvpl_rand_search_prefix)

## Targets
if(NOT TARGET nvpl_rand)
  include("${CMAKE_CURRENT_LIST_DIR}/nvpl_rand-targets.cmake")
  include("${CMAKE_CURRENT_LIST_DIR}/nvpl_rand-static-targets.cmake" OPTIONAL)

  # Allow alias to targets
  set_target_properties(nvpl_rand PROPERTIES IMPORTED_GLOBAL 1)
  set_target_properties(nvpl_rand_mt PROPERTIES IMPORTED_GLOBAL 1)
  if(TARGET nvpl_rand_static)
    set_target_properties(nvpl_rand_static PROPERTIES IMPORTED_GLOBAL 1)
  endif()
  if(TARGET nvpl_rand_mt_static)
    set_target_properties(nvpl_rand_mt_static PROPERTIES IMPORTED_GLOBAL 1)
  endif()
endif()

if(TARGET nvpl_rand_static)
  set(nvpl_rand_STATIC_LIBRARIES nvpl_rand_static)
endif()
set(nvpl_rand_SHARED_LIBRARIES nvpl_rand)

if(TARGET nvpl_rand_mt_static)
  set(nvpl_rand_mt_STATIC_LIBRARIES nvpl_rand_mt_static)
endif()
set(nvpl_rand_mt_SHARED_LIBRARIES nvpl_rand_mt)

if(NOT TARGET nvpl::rand)
  add_library(nvpl::rand ALIAS nvpl_rand)
endif()
if(NOT TARGET nvpl::rand_shared)
  add_library(nvpl::rand_shared ALIAS nvpl_rand)
endif()
if(TARGET nvpl_rand_static AND NOT TARGET nvpl::rand_static)
  add_library(nvpl::rand_static ALIAS nvpl_rand_static)
endif()

if(NOT TARGET nvpl::rand_mt)
  add_library(nvpl::rand_mt ALIAS nvpl_rand_mt)
endif()
if(NOT TARGET nvpl::rand_mt_shared)
  add_library(nvpl::rand_mt_shared ALIAS nvpl_rand_mt)
endif()
if(TARGET nvpl_rand_mt_static AND NOT TARGET nvpl::rand_mt_static)
  add_library(nvpl::rand_mt_static ALIAS nvpl_rand_mt_static)
endif()

check_required_components(nvpl_rand)
if(NOT ${CMAKE_FIND_PACKAGE_NAME}_FIND_QUIETLY)
  message(STATUS "Found nvpl_rand: (Version:${nvpl_rand_VERSION}
                     CMakePackageDir:${CMAKE_CURRENT_LIST_DIR}
                     IncludeDir:${nvpl_rand_INCLUDE_DIR}
                     LibraryDir:${nvpl_rand_LIBRARY_DIR})")
endif()
